==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/eu.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: eu.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $

$text['title']          = 'Sistemaren Informazioa';

$text['vitals']         = 'Sistema';
$text['hostname']       = 'Zerbitzariaren izen Kanonikoa';
$text['ip']             = 'Entzuten duen IP-a';
$text['kversion']       = 'Kernel Bertsioa';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Piztutako denbora';
$text['users']          = 'Uneko Erabiltzaileak';
$text['loadavg']        = 'Karga ertainak';

$text['hardware']       = 'Hardwarezko Informazioa';
$text['numcpu']         = 'Prozasatzailea';
$text['cpumodel']       = 'Modeloa';
$text['mhz']            = 'Txip MHz';
$text['cache']          = 'Cache tamaina';
$text['bogomips']       = 'Sistemare Bogomips-ak';
$text['usb']            = 'USB Dispositiboak';
$text['pci']            = 'PCI Dispositiboak';
$text['ide']            = 'IDE Dispositiboak';
$text['scsi']           = 'SCSI Dispositiboak';

$text['netusage']       = 'Sarearen Erabilera';
$text['device']         = 'Dispositiboa';
$text['received']       = 'Jasotakoa';
$text['sent']           = 'Bidalitakoa';
$text['errors']         = 'Err/Huts';

$text['connections']    = 'Established Network Connections';

$text['memusage']       = 'Memoriaren Erabilpena';
$text['phymem']         = 'Memoria Fisikoa';
$text['swap']           = 'Disko Memoria';

$text['fs']             = 'Montatutako Fitxategi-sistemak';
$text['mount']          = 'Non montatuta';
$text['partition']      = 'Partizioa';

$text['percent']        = 'Ehunekoa';
$text['type']           = 'Mota';
$text['free']           = 'Aske';
$text['used']           = 'Erabilita';
$text['size']           = 'Tamaina';
$text['totals']         = 'Guztira';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ezer ez';

$text['capacity']       = 'Kapazitatea'; 

$text['template']       = 'Txantiloia';
$text['language']       = 'Langoaia';
$text['submit']         = 'Bidali';
$text['created']        = 'Sortzailea: ';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'egun';
$text['hours']          = 'ordu';
$text['minutes']        = 'minutu';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/eu.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: eu.php,v 1.10 2004/08/30 15:51:26 webbie Exp $

$text['title']          = 'Sistemaren Informazioa';

$text['vitals']         = 'Sistema';
$text['hostname']       = 'Zerbitzariaren izen Kanonikoa';
$text['ip']             = 'Entzuten duen IP-a';
$text['kversion']       = 'Kernel Bertsioa';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Piztutako denbora';
$text['users']          = 'Uneko Erabiltzaileak';
$text['loadavg']        = 'Karga ertainak';

$text['hardware']       = 'Hardwarezko Informazioa';
$text['numcpu']         = 'Prozasatzailea';
$text['cpumodel']       = 'Modeloa';
$text['cpuspeed']       = 'Txip MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache tamaina';
$text['bogomips']       = 'Sistemare Bogomips-ak';

$text['pci']            = 'PCI Dispositiboak';
$text['ide']            = 'IDE Dispositiboak';
$text['scsi']           = 'SCSI Dispositiboak';
$text['usb']            = 'USB Dispositiboak';

$text['netusage']       = 'Sarearen Erabilera';
$text['device']         = 'Dispositiboa';
$text['received']       = 'Jasotakoa';
$text['sent']           = 'Bidalitakoa';
$text['errors']         = 'Err/Huts';

$text['connections']    = 'Established Network Connections';

$text['memusage']       = 'Memoriaren Erabilpena';
$text['phymem']         = 'Memoria Fisikoa';
$text['swap']           = 'Disko Memoria';

$text['fs']             = 'Montatutako Fitxategi-sistemak';
$text['mount']          = 'Non montatuta';
$text['partition']      = 'Partizioa';

$text['percent']        = 'Ehunekoa';
$text['type']           = 'Mota';
$text['free']           = 'Aske';
$text['used']           = 'Erabilita';
$text['size']           = 'Tamaina';
$text['totals']         = 'Guztira';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ezer ez';

$text['capacity']       = 'Kapazitatea'; 

$text['template']       = 'Txantiloia';
$text['language']       = 'Langoaia';
$text['submit']         = 'Bidali';
$text['created']        = 'Sortzailea: ';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'egun';
$text['hours']          = 'ordu';
$text['minutes']        = 'minutu';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
